@@ -2,13 +2,12 @@ use {
     crate::{
         blockstore::Blockstore,
         blockstore_processor::{
-            self, BlockstoreProcessorError, BlockstoreProcessorResult, CacheBlockMetaSender,
-            ProcessOptions, TransactionStatusSender,
+            self, BlockstoreProcessorError, CacheBlockMetaSender, ProcessOptions,
+            TransactionStatusSender,
         },
         leader_schedule_cache::LeaderScheduleCache,
     },
     log::*,
-    solana_entry::entry::VerifyRecyclers,
     solana_runtime::{
         accounts_update_notifier_interface::AccountsUpdateNotifier,
         bank_forks::BankForks,
@@ -18,7 +17,7 @@ use {
         snapshot_package::AccountsPackageSender,
         snapshot_utils,
     },
-    solana_sdk::{clock::Slot, genesis_config::GenesisConfig},
+    solana_sdk::genesis_config::GenesisConfig,
     std::{fs, path::PathBuf, process, result},
 };
 
@@ -26,29 +25,12 @@ pub type LoadResult = result::Result<
     (
         BankForks,
         LeaderScheduleCache,
-        Option<Slot>,
         Option<StartingSnapshotHashes>,
     ),
     BlockstoreProcessorError,
 >;
 
-fn to_loadresult(
-    bpr: BlockstoreProcessorResult,
-    starting_snapshot_hashes: Option<StartingSnapshotHashes>,
-) -> LoadResult {
-    bpr.map(
-        |(bank_forks, leader_schedule_cache, last_full_snapshot_slot)| {
-            (
-                bank_forks,
-                leader_schedule_cache,
-                last_full_snapshot_slot,
-                starting_snapshot_hashes,
-            )
-        },
-    )
-}
-
-/// Load the banks and accounts
+/// Load the banks via genesis or a snapshot then processes all full blocks in blockstore
 ///
 /// If a snapshot config is given, and a snapshot is found, it will be loaded.  Otherwise, load
 /// from genesis.
@@ -65,7 +47,46 @@ pub fn load(
     accounts_package_sender: AccountsPackageSender,
     accounts_update_notifier: Option<AccountsUpdateNotifier>,
 ) -> LoadResult {
-    if let Some(snapshot_config) = snapshot_config {
+    let (mut bank_forks, leader_schedule_cache, starting_snapshot_hashes) = load_bank_forks(
+        genesis_config,
+        blockstore,
+        account_paths,
+        shrink_paths,
+        snapshot_config,
+        &process_options,
+        cache_block_meta_sender,
+        accounts_update_notifier,
+    );
+
+    blockstore_processor::process_blockstore_from_root(
+        blockstore,
+        &mut bank_forks,
+        &leader_schedule_cache,
+        &process_options,
+        transaction_status_sender,
+        cache_block_meta_sender,
+        snapshot_config,
+        accounts_package_sender,
+    )
+    .map(|_| (bank_forks, leader_schedule_cache, starting_snapshot_hashes))
+}
+
+#[allow(clippy::too_many_arguments)]
+pub fn load_bank_forks(
+    genesis_config: &GenesisConfig,
+    blockstore: &Blockstore,
+    account_paths: Vec<PathBuf>,
+    shrink_paths: Option<Vec<PathBuf>>,
+    snapshot_config: Option<&SnapshotConfig>,
+    process_options: &ProcessOptions,
+    cache_block_meta_sender: Option<&CacheBlockMetaSender>,
+    accounts_update_notifier: Option<AccountsUpdateNotifier>,
+) -> (
+    BankForks,
+    LeaderScheduleCache,
+    Option<StartingSnapshotHashes>,
+) {
+    let snapshot_present = if let Some(snapshot_config) = snapshot_config {
         info!(
             "Initializing bank snapshot path: {}",
             snapshot_config.bank_snapshots_dir.display()
@@ -79,64 +100,84 @@ pub fn load(
         )
         .is_some()
         {
-            return load_from_snapshot(
-                genesis_config,
-                blockstore,
-                account_paths,
-                shrink_paths,
-                snapshot_config,
-                process_options,
-                transaction_status_sender,
-                cache_block_meta_sender,
-                accounts_package_sender,
-                accounts_update_notifier,
-            );
+            true
         } else {
             info!("No snapshot package available; will load from genesis");
+            false
         }
     } else {
         info!("Snapshots disabled; will load from genesis");
-    }
+        false
+    };
 
-    if process_options
-        .accounts_db_config
-        .as_ref()
-        .and_then(|config| config.filler_account_count)
-        .unwrap_or_default()
-        > 0
-    {
-        panic!("filler accounts specified, but not loading from snapshot");
-    }
-
-    info!("Processing ledger from genesis");
-    to_loadresult(
-        blockstore_processor::process_blockstore(
+    let (bank_forks, starting_snapshot_hashes) = if snapshot_present {
+        bank_forks_from_snapshot(
             genesis_config,
-            blockstore,
             account_paths,
+            shrink_paths,
+            snapshot_config.as_ref().unwrap(),
             process_options,
-            cache_block_meta_sender,
-            snapshot_config,
-            accounts_package_sender,
             accounts_update_notifier,
-        ),
-        None,
-    )
+        )
+    } else {
+        if process_options
+            .accounts_db_config
+            .as_ref()
+            .and_then(|config| config.filler_account_count)
+            .unwrap_or_default()
+            > 0
+        {
+            panic!("filler accounts specified, but not loading from snapshot");
+        }
+
+        info!("Processing ledger from genesis");
+        (
+            blockstore_processor::process_blockstore_for_bank_0(
+                genesis_config,
+                blockstore,
+                account_paths,
+                process_options,
+                cache_block_meta_sender,
+                accounts_update_notifier,
+            ),
+            None,
+        )
+    };
+
+    let mut leader_schedule_cache = LeaderScheduleCache::new_from_bank(&bank_forks.root_bank());
+    if process_options.full_leader_cache {
+        leader_schedule_cache.set_max_schedules(std::usize::MAX);
+    }
+
+    assert_eq!(bank_forks.banks().len(), 1);
+    if let Some(ref new_hard_forks) = process_options.new_hard_forks {
+        let root_bank = bank_forks.root_bank();
+        let hard_forks = root_bank.hard_forks();
+
+        for hard_fork_slot in new_hard_forks.iter() {
+            if *hard_fork_slot > root_bank.slot() {
+                hard_forks.write().unwrap().register(*hard_fork_slot);
+            } else {
+                warn!(
+                    "Hard fork at {} ignored, --hard-fork option can be removed.",
+                    hard_fork_slot
+                );
+            }
+        }
+    }
+
+    (bank_forks, leader_schedule_cache, starting_snapshot_hashes)
 }
 
 #[allow(clippy::too_many_arguments)]
-fn load_from_snapshot(
+fn bank_forks_from_snapshot(
     genesis_config: &GenesisConfig,
-    blockstore: &Blockstore,
     account_paths: Vec<PathBuf>,
     shrink_paths: Option<Vec<PathBuf>>,
     snapshot_config: &SnapshotConfig,
-    process_options: ProcessOptions,
-    transaction_status_sender: Option<&TransactionStatusSender>,
-    cache_block_meta_sender: Option<&CacheBlockMetaSender>,
-    accounts_package_sender: AccountsPackageSender,
+    process_options: &ProcessOptions,
     accounts_update_notifier: Option<AccountsUpdateNotifier>,
-) -> LoadResult {
+) -> (BankForks, Option<StartingSnapshotHashes>) {
     // Fail hard here if snapshot fails to load, don't silently continue
     if account_paths.is_empty() {
         error!("Account paths not present when booting from snapshot");
@@ -167,7 +208,7 @@ fn load_from_snapshot(
         deserialized_bank.set_shrink_paths(shrink_paths);
     }
 
-    let starting_full_snapshot_hash = FullSnapshotHash {
+    let full_snapshot_hash = FullSnapshotHash {
         hash: (
             full_snapshot_archive_info.slot(),
             *full_snapshot_archive_info.hash(),
@@ -176,7 +217,7 @@ fn load_from_snapshot(
     let starting_incremental_snapshot_hash =
         incremental_snapshot_archive_info.map(|incremental_snapshot_archive_info| {
             IncrementalSnapshotHash {
-                base: starting_full_snapshot_hash.hash,
+                base: full_snapshot_hash.hash,
                 hash: (
                     incremental_snapshot_archive_info.slot(),
                     *incremental_snapshot_archive_info.hash(),
@@ -184,23 +225,12 @@ fn load_from_snapshot(
             }
         });
     let starting_snapshot_hashes = StartingSnapshotHashes {
-        full: starting_full_snapshot_hash,
+        full: full_snapshot_hash,
         incremental: starting_incremental_snapshot_hash,
     };
 
-    let bank_forks = BankForks::new(deserialized_bank);
-    to_loadresult(
-        blockstore_processor::process_blockstore_from_root(
-            blockstore,
-            bank_forks,
-            &process_options,
-            &VerifyRecyclers::default(),
-            transaction_status_sender,
-            cache_block_meta_sender,
-            Some(snapshot_config),
-            accounts_package_sender,
-            full_snapshot_archive_info.slot(),
-        ),
+    (
+        BankForks::new(deserialized_bank),
         Some(starting_snapshot_hashes),
     )
 }
